@@ -5,33 +5,25 @@ use vars qw($loaded);
 
 #-------------------------------------------------------------------------------
 
-BEGIN {
-	$| = 1;
-	print "1..3\n";
-}
-
-END {
-    print "not ok 1\n" unless $loaded;
-}
+$| = 1;
 
 #-------------------------------------------------------------------------------
 
 {
     my $ntest=1;
-    sub ok     { return "ok ".$ntest++."\n"; }
-    sub not_ok { return "not ok ".$ntest++."\n"; }
+    sub ok      { return "ok ".$ntest++."\n"; }
+    sub not_ok  { return "not ok ".$ntest++."\n"; }
+    sub skipped { return "skipped ".$ntest++."\n"; }
 }
 
 #-------------------------------------------------------------------------------
 
-# test 1
-use SVG::Parser;
-$loaded = 1;
-print ok;
+my @tests=<test/*.pl>;
 
-# tests 2..N
-foreach my $test (<test/*.pl>) {
+print "1..",scalar(@tests),"\n";
+
+foreach my $test (@tests) {
   my $result=do $test;
-  print $result?ok:not_ok;
+  print $result?($result==2?skipped:ok):not_ok;
 }
 
